pub enum ClassExtensionKind {
Unique,
Ambiguous,
NoExtension,
}Expand description
Classification of the affine extension fiber at one grid node.
Variants
Unique
The base class has one extension.
Ambiguous
The base class has an affine family of extensions.
NoExtension
The base class has no extension.