pub struct PersistentClass {
pub id: BasisClassId,
pub group_id: IntervalGroupId,
pub basis_index: usize,
pub interval: Bar,
pub cocycle: Cocycle,
pub provenance: Option<PersistentClassProvenance>,
}Expand description
One vector in the declared basis of a persistent H1 class space.
Fields
id: BasisClassIdIdentifier derived from the class space, basis position, and cocycle.
group_id: IntervalGroupIdClass space that contains this basis vector.
basis_index: usizePosition in the canonical basis of the class space.
interval: BarH1 persistence interval.
cocycle: CocycleRepresentative on the caller’s graph.
provenance: Option<PersistentClassProvenance>Source binding for scalar Rips classes, when available.
Implementations
Sourceimpl PersistentClass
impl PersistentClass
Sourcepub fn provenance(&self) -> Option<&PersistentClassProvenance>
pub fn provenance(&self) -> Option<&PersistentClassProvenance>
Source binding for a scalar Rips class, when available.
Sourcepub fn validate_provenance(&self, graph: &SparseDistanceMatrix) -> Result<()>
pub fn validate_provenance(&self, graph: &SparseDistanceMatrix) -> Result<()>
Check that this class belongs to the supplied active graph.