pub struct GeometryBoundCoverageArtifact { /* private fields */ }Expand description
Coverage synthesis proof bound to checked finite planar geometry.
Implementations
Sourceimpl GeometryBoundCoverageArtifact
impl GeometryBoundCoverageArtifact
Sourcepub fn build(
coverage: CoverageSynthesisArtifact,
geometry: CoverageGeometry,
coverage_limits: CoverageSynthesisLimits,
geometry_limits: CoverageGeometryLimits,
) -> Result<Self>
pub fn build( coverage: CoverageSynthesisArtifact, geometry: CoverageGeometry, coverage_limits: CoverageSynthesisLimits, geometry_limits: CoverageGeometryLimits, ) -> Result<Self>
Bind an existing coverage proof to checked state coordinates.
Sourcepub fn geometry(&self) -> &CoverageGeometry
pub fn geometry(&self) -> &CoverageGeometry
Checked coordinates in state order.
Sourcepub fn coverage(&self) -> &CoverageSynthesisArtifact
pub fn coverage(&self) -> &CoverageSynthesisArtifact
Nested CoverageSynthesisArtifact.
Sourcepub fn verify(
&self,
coverage_limits: CoverageSynthesisLimits,
geometry_limits: CoverageGeometryLimits,
) -> Result<()>
pub fn verify( &self, coverage_limits: CoverageSynthesisLimits, geometry_limits: CoverageGeometryLimits, ) -> Result<()>
Recheck geometry, coverage, optimality, and the outer binding.
Sourcepub fn encode(
&self,
coverage_limits: CoverageSynthesisLimits,
geometry_limits: CoverageGeometryLimits,
decode_limits: GeometryBoundCoverageDecodeLimits,
) -> Result<Vec<u8>>
pub fn encode( &self, coverage_limits: CoverageSynthesisLimits, geometry_limits: CoverageGeometryLimits, decode_limits: GeometryBoundCoverageDecodeLimits, ) -> Result<Vec<u8>>
Encode canonical HOLOSGEO version 1 bytes.
Sourcepub fn decode(
bytes: &[u8],
coverage_limits: CoverageSynthesisLimits,
geometry_limits: CoverageGeometryLimits,
decode_limits: GeometryBoundCoverageDecodeLimits,
) -> Result<Self>
pub fn decode( bytes: &[u8], coverage_limits: CoverageSynthesisLimits, geometry_limits: CoverageGeometryLimits, decode_limits: GeometryBoundCoverageDecodeLimits, ) -> Result<Self>
Decode and verify canonical HOLOSGEO version 1 bytes.