pub enum CoverageSource {
Finite,
Affine {
scenario: u64,
edges: Vec<KineticEdge>,
start: f64,
end: f64,
},
}Expand description
Origin and completeness scope of a finite coverage state list.
Variants
Finite
States were supplied directly. No claim is made between them.
Affine
States are the complete threshold schedule of affine communication edges. Affine edge weights need not have a Euclidean realization.