pub struct CoverageState { /* private fields */ }Expand description
One finite communication state and its initially active sensors.
Implementations
Sourceimpl CoverageState
impl CoverageState
Sourcepub fn new(
scenario: u64,
step: u64,
graph: &SparseDistanceMatrix,
base_vertices: Vec<usize>,
broadcast_radius: f64,
) -> Result<Self>
pub fn new( scenario: u64, step: u64, graph: &SparseDistanceMatrix, base_vertices: Vec<usize>, broadcast_radius: f64, ) -> Result<Self>
Construct a state from a graph of every possible communication edge.
Sourcepub fn base_vertices(&self) -> &[usize]
pub fn base_vertices(&self) -> &[usize]
Sensors active before selecting a plan.
Sourcepub fn possible_edges(&self) -> &[KineticEdgeKey]
pub fn possible_edges(&self) -> &[KineticEdgeKey]
Communication edges available when both endpoints are active.