pub enum InterfaceMode {
Relative,
Materialized,
Disjoint,
ZeroSimplex,
ZeroCone,
}Expand description
Algebra retained by one separator interface.
Variants
Relative
The interface stores a filtered core relative to its parent boundary.
Materialized
The interface stores a reduction over its full vertex scope.
Disjoint
The scope is a disjoint union of its child scopes.
ZeroSimplex
Child scopes meet in one zero-filtration simplex.
ZeroCone
Child scopes meet in a zero-filtration flag cone.