#[non_exhaustive]pub enum InterventionStatus {
Optimal,
BoundedGap,
BudgetLimited,
}Expand description
Strength of the returned intervention claim.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Optimal
The feasible edit meets its lower bound inside the checked region.
BoundedGap
The feasible edit has distinct checked lower and upper bounds.
BudgetLimited
The declared candidate budget ended without a continued feasible edit.