pub struct KineticGraphState {
pub kind: KineticGraphStateKind,
pub graph: SparseDistanceMatrix,
}Expand description
One active graph in a fixed-scale kinetic schedule.
Fields
kind: KineticGraphStateKindEndpoint, open cell, or exact event represented by this state.
graph: SparseDistanceMatrixActive graph at the represented time or open cell.