pub struct ProgramDiagramState { /* private fields */ }Expand description
Stateful diagram evaluation with lazy materialization of class spaces.
Implementations
Sourceimpl ProgramDiagramState
impl ProgramDiagramState
Sourcepub fn from_program(program: &PersistenceProgram) -> Self
pub fn from_program(program: &PersistenceProgram) -> Self
Copy a compiled program into stateful diagram evaluation.
Sourcepub fn advance(
&mut self,
updated: &SparseDistanceMatrix,
) -> Result<ProgramDiagramUpdate>
pub fn advance( &mut self, updated: &SparseDistanceMatrix, ) -> Result<ProgramDiagramUpdate>
Advance the state and return only the exact persistence diagram.
Sourcepub fn materialize(&mut self) -> Result<&ExplainedDiagram>
pub fn materialize(&mut self) -> Result<&ExplainedDiagram>
Materialize the current canonical class spaces and critical pairs.
Sourcepub fn into_program(self) -> Result<PersistenceProgram>
pub fn into_program(self) -> Result<PersistenceProgram>
Materialize and consume this state as a normal persistence program.
This method consumes the state even when materialization returns an
error. Call ProgramDiagramState::materialize when the state must
remain available after a failed operation.