ProgramWork

Struct ProgramWork 

pub struct ProgramWork {
    pub edges_checked: usize,
    pub h0_edges_scanned: usize,
    pub guards_checked: usize,
    pub atoms_touched: usize,
    pub atoms_reused: usize,
    pub atoms_repaired: usize,
    pub atoms_rebuilt: usize,
    pub reduction_columns_reused: usize,
    pub reduction_columns_reduced: usize,
    pub reduction_column_additions: usize,
}
Exact work charged to one program evaluation or update.

Fields

edges_checked: usize

Listed edges compared with the current program input.

h0_edges_scanned: usize

Edges read by the H0 computation.

guards_checked: usize

Result-sensitive algebraic guards checked.

atoms_touched: usize

Cyclic atoms containing a changed edge.

atoms_reused: usize

Touched atoms reused without reduction.

atoms_repaired: usize

Touched atoms repaired by reducing a suffix.

atoms_rebuilt: usize

Touched atoms whose explained state was rebuilt without suffix repair.

reduction_columns_reused: usize

Boundary columns retained during reduction repair.

reduction_columns_reduced: usize

Boundary columns processed during reduction repair.

reduction_column_additions: usize

Sparse column additions performed during reduction repair.