pub enum ZigzagDirection {
Forward,
Backward,
}Expand description
Direction of one arrow between adjacent module nodes.
Variants
Forward
The map goes from the left node to the right node.
Backward
The map goes from the right node to the left node.