#[non_exhaustive]pub enum ContinuationKind {
Isomorphism,
Split,
Merge,
Mixing,
Birth,
Death,
Ambiguous,
}Expand description
Algebraic relation between class spaces across one update.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Isomorphism
One old space maps bijectively to one new space.
Split
One old space contributes to several new spaces.
Merge
Several old spaces contribute to one new space.
Mixing
Several old and new spaces share exact basis vectors.
Birth
A new space has no exact old basis vector.
Death
An old space has no exact new basis vector.
Ambiguous
A proper subset of the vectors has an exact declared continuation.