pub struct ProgramWork {
pub edges_checked: usize,
pub h0_edges_scanned: usize,
pub guards_checked: usize,
pub atoms_touched: usize,
pub atoms_reused: usize,
pub atoms_repaired: usize,
pub atoms_rebuilt: usize,
pub reduction_columns_reused: usize,
pub reduction_columns_reduced: usize,
pub reduction_column_additions: usize,
}Expand description
Exact work charged to one program evaluation or update.
Fields
edges_checked: usizeListed edges compared with the current program input.
h0_edges_scanned: usizeEdges read by the H0 computation.
guards_checked: usizeResult-sensitive algebraic guards checked.
atoms_touched: usizeCyclic atoms containing a changed edge.
atoms_reused: usizeTouched atoms reused without reduction.
atoms_repaired: usizeTouched atoms repaired by reducing a suffix.
atoms_rebuilt: usizeTouched atoms whose explained state was rebuilt without suffix repair.
reduction_columns_reused: usizeBoundary columns retained during reduction repair.
reduction_columns_reduced: usizeBoundary columns processed during reduction repair.
reduction_column_additions: usizeSparse column additions performed during reduction repair.